@@ -77,8 +77,11 @@ class FileLoader(object):
                 f = open('%s/templates/%s' % (app_name, path))
             except (IOError, ValueError):
                 assert 0, 'template not found: %s' % path
+
         path = os.path.normpath(os.path.join(os.getcwd(), f.name))
         self.mtimes[path] = os.path.getmtime(path)
-        return (f.read().decode('utf-8'), path,
-            lambda: self.mtimes[path] == os.path.getmtime(path))
+        source = f.read().decode('utf-8')
+        source = '\n'.join(line.lstrip() for line in source.splitlines())
+        return (source, path,
+                lambda: self.mtimes[path] == os.path.getmtime(path))
 file_loader = FileLoader().load
